@@ -22,6 +22,8 @@
  *
  */
 
+#include "config.h"
+
 #include "cc-timezone-map.h"
 #include <math.h>
 #include <string.h>
@@ -77,8 +79,8 @@ static CcTimezoneMapOffset color_codes[] =
     {-9.0, 128, 0, 0, 255 },
     {-8.0, 170, 0, 0, 255 },
     {-7.0, 212, 0, 0, 255 },
-    {-6.0, 255, 0, 1, 255 }, // north
-    {-6.0, 255, 0, 0, 255 }, // south
+    {-6.0, 255, 0, 1, 255 }, /* north */
+    {-6.0, 255, 0, 0, 255 }, /* south */
     {-5.0, 255, 42, 42, 255 },
     {-4.5, 192, 255, 0, 255 },
     {-4.0, 255, 85, 85, 255 },
